@@ -2,9 +2,11 @@
 
 mod models;
 mod optimize;
-mod periodic;
+pub mod periodic;
 mod scheduled;
+mod utils;
 
 pub use models::{DateLike, InvalidPaymentsError};
-pub use periodic::{fv, ipmt, irr, mirr, nfv, nper, npv, pmt, ppmt, pv, rate};
-pub use scheduled::{xfv, xirr, xnfv, xnpv};
+pub use periodic::*;
+pub use scheduled::*;
+pub mod private_equity;
